@@ -138,8 +138,16 @@ class ActionConfirmOrder(AbstractAction):
             response_raw.raise_for_status()
             response_dict = response_raw.json()
         except requests.HTTPError as e:
-            logger.fatal(response_raw.status_code)
-            logger.fatal(response_raw.text)
+            status_code = getattr(response_raw, "status_code", "No status_code found.")
+            text = getattr(response_raw, "text", "No text found.")
+            response_dict = getattr(response_raw, "json", "No json found.")
+            logger.fatal(status_code)
+            logger.fatal(text)
+            logger.fatal(response_dict)
+            if raw is True:
+                return response_dict
+            else:
+                return None
         except Exception as e:
             logger.fatal(e)
             return None
